bibliotheca Augustana

<<< Übersicht <<< vorige Seite nächste Seite >>>
BIBLIOTHECA AUGUSTANA

Das Nibelungenlied

1190/1200

| # Handschrift B ## 16. Aventiure
___________________________________________________
| ### Gventher vnd Hagene di recken vil balt ### lobten mit intrwen ein pirsen in den walt ### mit ir scharffen geren si wolden iagen swin ### bern vnd wisende waz moehte chvners gesin ### Da mit reit ovch Sifrit in herlichem site ### maniger hande spise fvrte man in mite ### zeinem chlaten brvnnen verlos er sit den lip [333a] ### daz het geraten Prvnnhilt des kvnich Gvntheres wip
###### 915 | ### Do gie der degen chvne da er Crimhilde <vant> ### do was nv vf gesovmet sin edel pirsgewant ### sin vnd siner gesellen si wolden vber Rin ### done dorfte Criemhilde nimmer leider gesin
| ### Di sine trivttinne chvst er an den mvnt ### got laze mich dich vrowe gesehen noch gesvnt ### vnd mich div dinen ovgen mit holden magen din ### soltv chvercewilen ine mach hie heime niht gesin
###### 917 | ### Do gedahtes an div mære sine torster niht gesagen ### div si da Hagenen sagete do begonde klagen ### div edel chveneginne daz si ie gewan den lip ### do weinete ane mazze des herren Sifrides wip
###### 918 | ### Si sprach zv dem recken lat iwer iagen sin ### mir trovmte hinat wi zwei wildiv swin ### iageten veber heide da wrden blvomen rot ### daz ich so sere weine des get mir wærliche not
| ### Ich fverhte harte sere ettelichen rat ### ob man der deheinem missedienet hat ### di vns gefvgen chvennen vientlichen haz ### belibet lieber herre mit rehten triwen rat ich daz
###### 920 | ### Er sprach min trivtinne ich chvm in chvrcen tagen ### ine weiz hie niht der livte di mir iht hazzes tragen ### alle dine mage sint mir gemeine holt ### ovch han ich an den degenen hie niht anders versolt
###### 921 | ### Neina herre Sifrit ia fverht ich dinen val ### mir trovmte hinte leide wi ob dir ce tal ### vielen zwene berge ine gesach dich nimmer me ### wil dv von mir scheiden daz tvt mir an dem hercen we
| ### Er vmbvie mit handen daz tvgentriche wip ### mit minnechlichem chvessen trvt er ir schonen lip ### mit vrlovbe er dannen shiet in chvrcer stvnt ### sine gesach in leider dar nach nimmer mer gesvnt
###### 923 | ### Do ritten si von dannen in einen tieffen walt ### dvrch chvrcewile willen vil manich ritter balt ### volgeten Gvnthere vnd sinen man ### Gêr vnd Giselher di waren da heime bestan
###### 924 | ### Geladen vil der rosse chom vor in veber den Rin ### di den iagetgesellen brot vnd win ### daz vleihs mit den visschen vnd manigen andern rat ### den ein chvnich so riche vil harte pillichen hat
| ### Si hiezen herbergen fver den grvnen walt ### gegen des waldes ablovffe di stolcen ieger balt ### da si da iagen solden vf einen wert vil breit ### da was ovch chomen Sifrit daz [333b] wart dem chvenege geseit
###### 926 | ### Von den iagtgesellen wrden do gar bestan ### div warte in allen enden do sprach der chvene man ### Sifrit der vil starche wer sol vns in den walt ### wisen nach dem wilde ir helde chvne vnd balt
###### 927 | ### Welle wir vns scheiden sprach do Hagene ### ê daz wir beginnen hie ce iagene ### da bi wir mvegen bechennen ich vnd di herren min ### wer di besten iegere an dirre waltreise sin
| ### Livte vnd gehvende svln wir teilen gar ### so cher ietslicher swar er gerne var ### swer danne iage daz beste des sol er haben danch ### do wart der ieger biten bi ein ander niht ce lanch
###### 929 | ### Do sprach der herre Sifrit ich han der hvnde rat ### niwan einen bracken der so genozzen hat ### daz er di verte erchenne der tiere dvrch den tan ### wir chomen wol ce iegede sprach der Criemhilde man
###### 930 | ### Do nam ein alter iegere einen gvten spverhvnt ### er brahte den herren in einer chvrcer stvnt ### da si vil tieren fvnden swaz der von lægere stvnt ### di eriagten di gesellen als noch gvte ieger tvnt
| ### Swaz ir der bracke erspranchte di slvch mit siner hant ### Sifrit der vil chvene der helt von Niderlant ### sin ros lieff so sere daz ir im niht entran ### den lop vor in allen er an dem iegde gewan
###### 932 | ### Er was in allen dingen biderbe genvch ### tier was daz erste daz er ce tode slvch ### ein vil starchez <halp> mit der sinen hant ### dar nach er vil schiere einen vngefvegen lewen vant
###### 933 | ### Do den der bracke erspranchte den shoz er mit dem bogen ### eine starche strale het er dar in gezogen ### der lev lief nach dem shvzze wan drier sprvenge lanch ### di sinen iagtgesellen di sagten Sifride danch
| ### Dar nach slvch er shiere einen wisent vnd einen elch ### starcher vower viere vnd einen grimmen shælch ### sin ross in trvch so balde daz ir im niht entran ### hirzze oder hinden chvnde im wenich engan
###### 935 | ### Einen eber grozen den vant der spverhvnt ### als er begvnde vliehen do chom an der stvnt ### des selben geiedes meister er bestvnt in vf der sla ### daz swin vil zornechlichen lief an den helt san
###### 936 | ### Do slvch in mit dem swerte der Criemhil [334a] de man ### ezen het ein ander ieger so samfte niht getan ### do er in het ervellet man vie der spverhvnt ### do wart sin iaget daz riche wol den Bvergvnden chvnt
| ### Do sprachen sin iegere mvegez mit fvege wesen ### so lat vns her Sifrit der tier ein teil genesen ### ir tvt vns hivte lære den berch vnd ovch den walt ### des begonde smielen der degen chvene vnde balt
###### 938 | ### Do hortens allenthalben lvdem vnd doz ### von livte vnd ovch von hvnden was der schal so groz ### daz in da von antwrte der berch vnd ovch der tan ### vier vnt zweinzech rvore di ieger heten ver lan
###### 939 | ### Do mvsen vil der tiere vliesen da daz leben ### do wanden si daz fvegen daz man in solde geben ### den pris von dem geiede des chvnde niht geschæhen ### do der starche Sifrit wart cer fiwerstat gesæhen
| ### Daz iagt was ergangen vnd ovch niht gar ### di cer fiwerstete wolden di brahten mit in dar ### vil maniger tier hvete vnd wildes genvch ### hey waz man des cer chvchen des chvneges ingesinde trvch
###### 941 | ### Do hiez der chvenich chvenden den iegern vz erchorn ### daz er wold enbizzen do wart vil lvote ein horn ### zeiner stvnt geblasen da mit in wart erchant ### daz man den fvrsten edele da cen herbergen vant
###### 942 | ### Do sprach ein Sifrides iægere herre ich han vernomen ### von eines hornes dvzze daz wir nv svln chomen ### zv den herbergen antwrten ich des wil ### do wart nach den gesellen gevraget blasende vil
| ### Do sprach der herre Sifrit nv rvome ovch wir den tan ### sin ross trvch in ebene si ilten mit im dan ### si er spranchten mit ir shalle ein tier vil griwelich ### daz <was> ein ber wilde do sprach der degen hinder sich
###### 944 | ### Ich wil vns hergesellen gvter chvercewile wern ### wir svlt den bracken lazen ia sih ich einen bern ### der sol mit vns hinnen zen herbergen varn ### ern vliehe danne vil sere ern chan siches nimmer bewarn
###### 945 | ### Der bracke wart verlazen der bere spranchte von dan ### do wold in erriten der Criemhilde man ### er chom in ein gewelle done chondes niwet wesen ### <daz> starche tier do wande vor dem iægere genesen [334b]
| ### Do spranch von sinem rosse der stolze ritter gvt ### er begonde nach lovffen daz tier was vmbehvt ### ezen chonde im niht entrinnen do viench er iz cehant ### an aller slahte wnden der helt ez schiere gebant
| ### Crazcen vnd bizen chvnde ez niht den man ### er band ez zvme satele vf saz der snelle san ### er braht iz an di fiwerstat dvrch sinen hohen mvt ### ceiner chvrzewile der recke chvene vnd gvt
###### 948 | ### Wi rehte herliche er cen herbergen reit ### sin ger was vil michel starch vnde breit ### im hiench ein zier waffen hin nider an den sporn ### von vil rotem golde fvrt der herre ein shone horn
###### 949 | ### Von bezzerm prischewæte gehort ich nie gesagen ### einen rok von swarcem pfellel den sach man in tragen ### vnd eine hvt von zobele div riche was genvch ### hey waz er richer porten an sinem chochære trvch
| ### Von einem pantel was dar vber gezogen ### ein hvt dvrch di sveze ovch fvrt er einen bogen ### den man mit antwerche mvse ziehen dan ### der in spannen solde ern het ez selbe getan
###### 951 | ### Von einer lvdemes hvte was allez sin gewant ### von hovbet vnz an daz ende gestrevt <man> dar vffe vant ### vz der liehten rivhe vil manich goldes zein ### ce beiden sinen siten dem chvnem iegermeister schein
###### 952 | ### Do fvrt er Palmvngen ein ziere waffen breit ### daz was also scherpfe daz ez nie vermeit ### swa man ez slvch vf helme sin ecke waren gvt ### der herliche iæger was hohe gemvt
| ### Sit daz ich iv div mære gar bescheiden sol ### im was sin edel chocher vil gvter strale vol ### von gvldinen tvellen div sahs wol hende breit ### ez mvse vil balde sterben swaz er da mit versneit
###### 954 | ### Do reit der ritter edele vil weidenliche dan ### in sahen <dort> chomen her di Gvntheres man ### si lieffen im engegen vnd enpfiengen im daz march ### do fvrt er bi dem satel einen bern groz vn starch
###### 955 | ### Als er gestvnt von rosse do lost er im div bant ### von fvoze vnd ovch von mvnde do erlvote da cehant ### vil groze daz gehvende swaz des den bern sach ### daz tier ce walde wolde di livte heten vngemach
| ### Der ber von dem schalle dvrch di chvochen geriet ### hey waz er chvchenknehte von dem fiwer schiet ### vil <chezzel> wart gerve [335a] ret cefveret manich brant ### hey waz man gvter spise in der asschen ligen <vant>
###### 957 | ### Do sprvngem von dem sedele di herren vnd ir man ### der ber begonde zvernen der chvenich der hiez do lan ### allez daz gehvende daz an den seilen lach ### vnd wæriz wol verendet si heten vrolichen tach
###### 958 | ### Mit bogen vnd mit spiezen niht langer man daz lie ### do lieffen dar di snellen da der ber gie ### da was so vil der <hvnde> daz da niemen shoz ### von des livtes schalle daz gebirge allez erdoz
| ### Der ber begonde vliehen von den hvnden dan ### im chvnde niht gevolgen wan Criemhilde man ### der erlief in mit dem swerte ce tode er in do slvch ### hin wider zv dem fiwere den ber man do sider trvch
###### 960 | ### Do sprachen di daz sahen er wære ein creftech man ### di stolzen iagetgesellen hiez man cen tisschen gan ### vf einem shoenem anger saz ir da genvch ### hey waz man richer spise den edeln iegeren do trvch
###### 961 | ### Di <shenchen> chomen seine di tragen solden win ### ezen chvnde baz gedienet den helden nimmer sin ### heten si dar vnder niht so valschen mvt ### so wæren wol di recken vor allen schanden behvt
| ### Do sprach der herre Sifrit wnder mich des hat ### sit man vns von den chvchen git so manigen rat ### war vmb vns di shenchen bringen niht den win ### man enpflæge baz der iegere ich en wil niht iagetgeselle sin
###### 963 | ### Ich hete wol gedienet daz man min baz næme war ### der chvenich von sinem tissche sprach in valsche dar ### man sol iv gerne bvezen swes wir gebresten han ### daz ist von Hagenen schvlden er wil vns gern erdversten lan
###### 964 | ### Do sprach von Tronege Hagene vil lieber herre min ### ich wande daz daz pirsen hivte solde sin ### da cem Spehtsharte den win den sand ich dar ### sin wir hivte vngetrvnchen wi wol ich mere daz bewar
| ### Do sprach der herre Sifrit ir lip der hab vndanch ### man solde mir siben sovme met vnd lvtertranch ### haben her gefveret do des niht mohte sin ### do sold man vns gesidelt haben naher an den Rin
###### 966 | ### Do sprach von Tronege Hagene ir edel ritter balt ### ich weiz hie bi nahen einen brvnnen [335b] chalt ### daz ir niht en zvernet da svln wir hine gan ### der rat wart manigem degene ce grozen sorgen getan
###### 967 | ### Sifrit den recken twanch des tvrstes not ### den tissch er deste ziter rvchen dan gebot ### er wolde fver di berge zv dem brvnnen gan ### do was der rat mit meine von den rechen getan
| ### Div tier hiez man wægen fveren in daz lant ### div da hete verhowen div Sifrides hant ### man iah im grozer eren swer iz ie gesach ### Hagen sine triwe vil sere an Sifriden brach
###### 969 | ### Do si wolden dannen zv den linden breit ### do sprach von Tronege Hagene mir ist des vil geseit ### daz niht gevolgen chvenne der Criemhilde man ### swenne er wolde gahen hey wolde er vns daz sehen lan
###### 970 | ### Do sprach von Niderlande der chvene Sifrit ### daz mvget ir wol versvchen welt ir mir lovffen mit ### ce wette zv dem brvnnen so daz ist getan ### dem sol man iehen dannen den man sihet gewnnen han
| ### Nv welle ovch wirz versvchen sprach Hagene der degen ### do sprach der snelle Sifrit so wil ich mich legen ### fvor di iwern fvezze nider an das gras ### do er daz gehorte wi lieb ez Gvnthere was
###### 972 | ### Do sprach der degen chvene noch wil ich iv mere sagen ### allez min gewæte wil ich mit mir tragen ### den ger zv dem schilde vnd al min pirsgewant ### den chocher zv dem swerte vil schier er vmb gebant
###### 973 | ### Do zvgen si div chleider von dem libe dan ### in zwein wizzen hemden sach man si beide stan ### sam zwei wildiv pantel si lieffen dvrch den chle ### do sach man bi dem brvnnen den chvenen Sifriden ê
| ### Den pris an allen dingen trvch er vor manigem man ### daz swert daz lost er schiere den chocher leit er dan ### den starchen ger er leinte an der linden ast ### bi des brvnnen vlzze stvnt der herliche gast
###### 975 | ### Di Sifrides tvgende waren harte groz ### den schilt er leite nider al da der brvnne vloz ### swi harte in do dvrste der helt nine tranch ### ê daz der chvenich getrvnche des [336a] sagt er im boesen danch
###### 976 | ### Der brvnne der was chvle lvter vnd gvt ### Gvnther sich do neigete nider zv dem flvt ### als er het getrvnchen do riht er sih von dan ### alsam het <ovch> gerne der chvne Sifrit getan
| ### Do engalt er sine zvehte den bogen vnt daz swert ### daz trvch allez Hagene von im dannewert ### do sprang er hin wider da <er> den ger da vant ### er sach nach einem bilde an des chvenen gewant
###### 978 | ### Da der herre Sifrit ob dem brvnnen tranch ### er shoz in dvrch daz <Crvce> daz von der wnden spranch ### daz blvt im von dem hercen vaste an Hagenen wat ### so groze missewende ein helt nimmer mer begat
###### 979 | ### Den ger im gein dem hercen er do stechen lie ### also grimmechlichen ce flvehten Hagen nie ### gelief noch in der werlde vor deheinem man ### do sich der herre Sifrit der grozen wnden versan
###### 980 | ### <der> herre tobelichen von dem brvnnen spranch ### im ragete von dem hercen ein gerstange lanch ### der fverste wande vinden bogen oder swert ### so mvese wesen Hagen nach sinem dienste gewert
###### 981 | ### Do der sere wnde des swertes niht en vant ### done het et er niht mere want des shildes rant ### er zvchten von dem brvnnen do lief er Hagenen an ### done chvnde im niht entrinnen des chvnich Gvntheres man
###### 982 | ### Swi wnt er was cem tode so crefftechlich er slvch ### daz vz dem schilde dræte genvch ### <viel> des edelen gesteines der schilt vil gar cerbrast ### sich hete gerne errochen der vil herliche gast
| ### Do was gestrvchet Hagene vor siner hant ce tal ### von des slages creffte der wert vil lvt erhal ### het er daz swert enhande so wærez Hagenen tot ### so sere zvrnt der wnde des gie im wærlichen not
###### 984 | ### Erblichen was sin varwe ern chvnde niht gesten ### sines libes sterche mvse gar cergen ### wand er des todes zeichen in liehter varwe trvch ### sit wart er beweinet von schonen vrowen genvch
###### 985 | ### Do viel in di blvmen der Criemhilde man ### daz plvt von siner wnden sach man vil <· aste> gan ### do begonde er schelten des gie im groziv not ### di vf in geraten heten den vngetriwen tot [336b]
###### 986 | ### <Do> sprach der verch wnde ia ir vil boesen zagen ### waz helffent miniv dienest daz ir mich habt erslagen ### ich was ie getriwe des ich engolten han ### ir habt an iwern magen leider vbele getan
###### 987 | ### Di sint da von bescholten swaz ir wirt geborn ### her nach disen ziten ir habet iwern zorn ### gerochen also sere an dem libe min ### mit laster ir gescheiden svlt von gvten rechen sin
###### 988 | ### Di ritter alle lieffen da er erslagen lach ### æz was ir genvgen ein vrevdeloser tach ### di iht triwe heten von den wart er gechlæit ### daz het wol verdienet der ritter chven vnt gemeit
| ### Der kvenich von Bvrgvnden chlagte sinen tot ### do sprach der verch wnde ez ist ane not ### daz der nach schaden weinet der in hat getan ### der dienet michel schelten ez wære bezer verlan
###### 990 | ### Do sprach der grimme Hagene iane weiz ich waz er kleit ### allez hat nv ende vnser sorge vnt vnser leit ### wir vinden ir vil wenich di getverren vns bestan ### wol mich deich siner herschaft ce rate han getan
###### 991 | ### Ir mveget ivch lihte rvemen sprach do Sifrit ### het ich an iv erchennet den mortlichen sit ### ich hete wol behalten vor iv minen lip ### mich riwet niht so sere so vrov Criemhilt min wip
###### 992 | ### <Nv> mvze got erbarmen deich ie gewan den svn ### dem man daz itewizen sol nah den ziten tvn ### daz sine mage iemen mortliche han erslagen ### moht ich so sprach Sifrit daz sold ich pilliche chlagen
###### 993 | ### Do sprach iemerliche der verchwnde man ### welt ir chvenich edele triwen iht began ### in der werlt iemen lat iv bevolhen sin ### vf iwer genade di holden trivtinne min
###### 994 | ### Vnd lat si des geniezen daz si iwer swester si ### dvrch aller fvrsten tvgende wont ir mit triwen bi ### mir mvezen warten lange min vater vnd mine man ### ezen wart nie vrowen leider an liebem manne getan
| ### Di blvmen allenthalben von blvte wrden naz ### do rang er mit dem tode vnlange tet er daz ### want des todes waffen ie ce sere sneit ### done moht niht reden mere der recke chven vnt gemeit
###### 996 | ### Do di herren sahen daz der helt was tot ### si leiten in vf einen schilt der was von golde rot ### vnd wrden des ce rate wi daz sold ergan ### daz man ez verhæle daz ez hete Hagen getan [337a]
###### 997 | ### Do <sprachn> genvge vns ist vbel geschehen ### ir svlt ez heln alle vnt svlt geliche iehen ### da er rite eine iagen der Criemhilde man ### in slvegen schachære da er fvere dvrch den tan
###### 998 | ### <Do> sprach von Tronege Hagene ich <bringn> in daz lant ### mir ist vil vnmære vnd wirt ez ir bechant ### div so hat betrvebet den Prvennhilde mvt ### ez ahtet mich vil ringe swaz si weinens getvt

<<< Übersicht <<< vorige Seite nächste Seite >>>